@@ -1,6 +1,6 @@
 package EWS::Client;
 BEGIN {
-  $EWS::Client::VERSION = '1.200001';
+  $EWS::Client::VERSION = '1.300000';
 }
 use Moose;
 
@@ -11,6 +11,8 @@ with qw/
     EWS::Client::Role::FindFolder
     EWS::Client::Role::GetFolder
     EWS::Client::Role::ExpandDL
+    EWS::Client::Role::GetUserAvailability
+    EWS::Client::Role::ResolveNames
 /;
 use EWS::Client::Contacts;
 use EWS::Client::Calendar;
