@@ -46,6 +46,9 @@ sub _build_transporter {
             $self->username, $self->password);
     }
 
+    # XXX disable all security checks
+    $t->userAgent->ssl_opts( verify_hostname => 0, SSL_verify_mode => 0x00 );
+
     return $t;
 }
 
@@ -63,6 +66,20 @@ sub _build_wsdl {
     $wsdl->importDefinitions('ews-types.xsd');
     $wsdl->importDefinitions('ews-messages.xsd');
 
+    # skip the t:Culture element in the ResolveNames response
+    # it breaks the XML Parser for some reason
+    $wsdl->addHook(path => "{http://schemas.microsoft.com/exchange/services/2006/messages}ResolveNamesResponse/ResponseMessages/ResolveNamesResponseMessage/ResolutionSet/Resolution/Contact",
+        before => sub {
+            my ($xml, $path) = @_;
+            my @nodes = $xml->childNodes();
+            foreach my $node (@nodes) {
+                if($node->nodeName eq 't:Culture'){
+                    $xml->removeChild($node);
+                }
+            }
+            return $xml;
+         });
+
     return $wsdl;
 }
 
